@@ -9,11 +9,11 @@ LaTeX::TikZ::Formatter - LaTeX::TikZ formatter object.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 DESCRIPTION
 
@@ -29,8 +29,8 @@ use LaTeX::TikZ::Interface;
 
 use LaTeX::TikZ::Tools;
 
-use Any::Moose;
-use Any::Moose 'Util::TypeConstraints';
+use Mouse;
+use Mouse::Util::TypeConstraints;
 
 =head1 ATTRIBUTES
 
@@ -45,7 +45,7 @@ Defaults to C<cm>.
 
 has 'unit' => (
  is      => 'ro',
- isa     => enum([ qw/cm pt/ ]),
+ isa     => enum([ qw<cm pt> ]),
  default => 'cm',
 );
 
@@ -131,7 +131,7 @@ sub id {
 
  my $origin = $tikz->origin;
  if (defined $origin) {
-  my ($x, $y) = map $origin->$_, qw/x y/;
+  my ($x, $y) = map $origin->$_, qw<x y>;
   $origin = "($x;$y)";
  } else {
   $origin = "(0;0)";
@@ -139,10 +139,12 @@ sub id {
 
  join $;, map {
   defined() ? "$_" : '(undef)';
- } map($tikz->$_, qw/unit format scale width height/), $origin;
+ } map($tikz->$_, qw<unit format scale width height>), $origin;
 }
 
-=head2 C<render @sets>
+=head2 C<render>
+
+    my ($header_lines, $mod_lines, $content_lines) = $formatter->render(@sets);
 
 Processes all the L<LaTeX::TikZ::Set> objects given in C<@sets> to produce the actual TikZ code to insert in the LaTeX file.
 First, all the mods applied to the sets and their subsets are collected, and a declaration is emitted if needed for each of them by calling L<LaTeX::TikZ::Mod/declare>.
@@ -212,11 +214,9 @@ my $find_mods = do {
     }
    }
 
-   my @subsets = $set->isa('LaTeX::TikZ::Set::Sequence')
+   my @subsets = $set->does('LaTeX::TikZ::Set::Container')
                  ? $set->kids
-                 : $set->isa('LaTeX::TikZ::Set::Path')
-                   ? $set->ops
-                   : ();
+                 : ();
 
    $find_mods_rec->($_, $layers, $others) for @subsets;
   });
@@ -298,7 +298,9 @@ sub render {
  return \@header, \@decls, @bodies;
 }
 
-=head2 C<len $len>
+=head2 C<len>
+
+    my $physical_len = $formatter->len($logical_len);
 
 Format the given length according to the formatter options.
 
@@ -312,7 +314,9 @@ sub len {
  sprintf $tikz->format . $tikz->unit, $len * $tikz->scale;
 }
 
-=head2 C<angle $theta>
+=head2 C<angle>
+
+    my $physical_angle = $formatter->angle($logical_angle);
 
 Format the given angle (in radians) according to the formatter options.
 
@@ -328,7 +332,9 @@ sub angle {
  sprintf $tikz->format, POSIX::ceil($a);
 }
 
-=head2 C<label $name, $pos>
+=head2 C<label>
+
+    my $label = $formatter->label($name, $pos);
 
 Returns the TikZ code for a point labeled C<$name> at position C<$pos> according to the formatter options.
 
@@ -388,7 +394,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
