@@ -9,17 +9,19 @@ LaTeX::TikZ::Interface - LaTeX::TikZ public interface register and loader.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Sub::Name ();
 
 =head1 METHODS
 
-=head2 C<< register $keyword => $code >>
+=head2 C<register>
+
+    LaTeX::Tikz::Interface->register($keyword => $code)
 
 Registers C<$code> to be available with C<< Tikz->$keyword >>.
 
@@ -69,8 +71,9 @@ sub load {
 
  require LaTeX::TikZ::Set::Raw;       # raw
 
- require LaTeX::TikZ::Set::Path;      # path
+ require LaTeX::TikZ::Set::Union;     # union, path
  require LaTeX::TikZ::Set::Sequence;  # seq
+ require LaTeX::TikZ::Set::Chain;     # chain, join
 
  require LaTeX::TikZ::Set::Point;     # point
  require LaTeX::TikZ::Set::Line;      # line
@@ -85,6 +88,7 @@ sub load {
  require LaTeX::TikZ::Mod::Clip;      # clip
  require LaTeX::TikZ::Mod::Layer;     # layer
 
+ require LaTeX::TikZ::Mod::Scale;     # scale
  require LaTeX::TikZ::Mod::Width;     # width
  require LaTeX::TikZ::Mod::Color;     # color
  require LaTeX::TikZ::Mod::Fill;      # fill
@@ -114,7 +118,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
