@@ -9,11 +9,11 @@ LaTeX::TikZ::Mod::Clip - A modifier that clips sequences with a path.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Sub::Name ();
 
@@ -25,7 +25,7 @@ use LaTeX::TikZ::Functor;
 
 use LaTeX::TikZ::Tools;
 
-use Any::Moose;
+use Mouse;
 
 =head1 RELATIONSHIPS
 
@@ -45,7 +45,7 @@ The path that specifies the clipped area.
 
 has clip => (
  is       => 'ro',
- does     => 'LaTeX::TikZ::Set::Op',
+ does     => 'LaTeX::TikZ::Set::Path',
  required => 1,
 );
 
@@ -211,7 +211,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
