@@ -9,15 +9,15 @@ LaTeX::TikZ::Mod::Fill - A modifier that fills a closed path with a color.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use LaTeX::TikZ::Interface;
 
-use Any::Moose;
+use Mouse;
 
 =head1 RELATIONSHIPS
 
@@ -98,7 +98,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
