@@ -9,17 +9,14 @@ LaTeX::TikZ::Mod::Formatted - Intermediate object between a modifier object and
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-use Any::Moose;
-use Any::Moose 'Util::TypeConstraints' => [
- 'enum',
- qw(coerce from via),
-];
+use Mouse;
+use Mouse::Util::TypeConstraints qw<enum coerce from via>;
 
 =head1 ATTRIBUTES
 
@@ -29,7 +26,7 @@ use Any::Moose 'Util::TypeConstraints' => [
 
 has 'type' => (
  is       => 'ro',
- isa      => enum([ qw/clip layer raw/ ]),
+ isa      => enum([ qw<clip layer raw> ]),
  required => 1,
 );
 
@@ -84,7 +81,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
