@@ -9,11 +9,11 @@ LaTeX::TikZ::Mod::Layer - A modifier that specifies a drawing layer.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Scalar::Util ();
 use List::Util   ();
@@ -22,8 +22,8 @@ use LaTeX::TikZ::Mod::Formatted;
 
 use LaTeX::TikZ::Interface;
 
-use Any::Moose;
-use Any::Moose 'Util::TypeConstraints';
+use Mouse;
+use Mouse::Util::TypeConstraints;
 
 =head1 RELATIONSHIPS
 
@@ -275,7 +275,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
