@@ -9,18 +9,18 @@ LaTeX::TikZ::Mod::Pattern::Lines - An hatched pattern modifier.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Sub::Name ();
 
 use LaTeX::TikZ::Tools;
 
-use Any::Moose;
-use Any::Moose 'Util::TypeConstraints';
+use Mouse;
+use Mouse::Util::TypeConstraints;
 
 =head1 RELATIONSHIPS
 
@@ -125,7 +125,7 @@ around 'BUILDARGS' => sub {
  confess('Can\'t specify an explicit template for a '. __PACKAGE__ .' pattern')
                                                       if exists $args{template};
 
- my @params = qw/direction line_width space_width/;
+ my @params = qw<direction line_width space_width>;
 
  my $meta = $class->meta;
  for (@params) {
@@ -186,7 +186,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
