@@ -9,17 +9,17 @@ LaTeX::TikZ::Mod::Width - A modifier that sets the line width.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use LaTeX::TikZ::Interface;
 
 use LaTeX::TikZ::Tools;
 
-use Any::Moose;
+use Mouse;
 
 =head1 RELATIONSHIPS
 
@@ -37,7 +37,7 @@ with 'LaTeX::TikZ::Mod';
 
 has 'width' => (
  is       => 'ro',
- isa      => 'Int',
+ isa      => 'Num',
  required => 1,
 );
 
@@ -100,7 +100,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
