@@ -9,20 +9,18 @@ LaTeX::TikZ::Point - Internal representation of what LaTeX::TikZ consider as 2D
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-use Any::Moose;
-use Any::Moose 'Util::TypeConstraints' => [ qw/
- coerce
- from
- via
+use Mouse;
+use Mouse::Util::TypeConstraints qw<
+ coerce from via
  find_type_constraint
  register_type_constraint
-/ ];
+>;
 
 =head1 ATTRIBUTES
 
@@ -55,7 +53,7 @@ use LaTeX::TikZ::Meta::TypeConstraint::Autocoerce;
 register_type_constraint(
  LaTeX::TikZ::Meta::TypeConstraint::Autocoerce->new(
   name   => 'LaTeX::TikZ::Point::Autocoerce',
-  parent => find_type_constraint(__PACKAGE__),
+  target => find_type_constraint(__PACKAGE__),
  ),
 );
 
@@ -96,7 +94,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
