@@ -9,22 +9,17 @@ LaTeX::TikZ::Point::Math::Complex - Coerce Math::Complex points into LaTeX::TikZ
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Math::Complex;
 
 use LaTeX::TikZ::Point;
 
-use Any::Moose 'Util::TypeConstraints' => [ qw/
- class_type
- coerce
- from
- via
-/ ];
+use Mouse::Util::TypeConstraints qw<class_type coerce from via>;
 
 my $mc_tc = class_type 'Math::Complex';
 
@@ -51,7 +46,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
