@@ -9,13 +9,13 @@ LaTeX::TikZ::Set::Arrow - A combined set object representing an arrow.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-use Carp;
+use Carp ();
 
 use LaTeX::TikZ::Point;
 
@@ -23,7 +23,7 @@ use LaTeX::TikZ::Set::Line;
 
 use LaTeX::TikZ::Interface;
 
-use Any::Moose 'Util::TypeConstraints' => [ 'find_type_constraint' ];
+use Mouse::Util::TypeConstraints 'find_type_constraint';
 
 my $ltp_tc = find_type_constraint('LaTeX::TikZ::Point::Autocoerce');
 
@@ -76,7 +76,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
