@@ -9,11 +9,11 @@ LaTeX::TikZ::Set::Circle - A set object representing a circle.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use LaTeX::TikZ::Set::Point;
 
@@ -22,16 +22,16 @@ use LaTeX::TikZ::Functor;
 
 use LaTeX::TikZ::Tools;
 
-use Any::Moose;
-use Any::Moose 'Util::TypeConstraints';
+use Mouse;
+use Mouse::Util::TypeConstraints;
 
 =head1 RELATIONSHIPS
 
-This class consumes the L<LaTeX::TikZ::Set::Op> role, and as such implements the L</path> method.
+This class consumes the L<LaTeX::TikZ::Set::Path> role, and as such implements the L</path> method.
 
 =cut
 
-with 'LaTeX::TikZ::Set::Op';
+with 'LaTeX::TikZ::Set::Path';
 
 =head1 ATTRIBUTES
 
@@ -73,6 +73,18 @@ sub path {
  $set->center->path(@_) . ' circle (' . $tikz->len($set->radius) . ')';
 }
 
+=head2 C<begin>
+
+=cut
+
+sub begin { $_[0]->center->begin }
+
+=head2 C<end>
+
+=cut
+
+sub end { $_[0]->center->end }
+
 LaTeX::TikZ::Interface->register(
  circle => sub {
   shift;
@@ -95,7 +107,7 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 SEE ALSO
 
-L<LaTeX::TikZ>, L<LaTeX::TikZ::Set>, L<LaTeX::TikZ::Set::Op>.
+L<LaTeX::TikZ>, L<LaTeX::TikZ::Set>, L<LaTeX::TikZ::Set::Path>.
 
 =head1 AUTHOR
 
@@ -116,7 +128,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
