@@ -9,26 +9,26 @@ LaTeX::TikZ::Set::Line - A set object representing a line.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use LaTeX::TikZ::Set::Point;
 
 use LaTeX::TikZ::Interface;
 use LaTeX::TikZ::Functor;
 
-use Any::Moose;
+use Mouse;
 
 =head1 RELATIONSHIPS
 
-This class consumes the L<LaTeX::TikZ::Set::Op> role, and as such implements the L</path> method.
+This class consumes the L<LaTeX::TikZ::Set::Path> role, and as such implements the L</path> method.
 
 =cut
 
-with 'LaTeX::TikZ::Set::Op';
+with 'LaTeX::TikZ::Set::Path';
 
 =head1 ATTRIBUTES
 
@@ -70,6 +70,18 @@ sub path {
  $set->from->path(@_) . ' -- ' . $set->to->path(@_);
 }
 
+=head2 C<begin>
+
+=cut
+
+sub begin { $_[0]->from->begin }
+
+=head2 C<end>
+
+=cut
+
+sub end { $_[0]->to->end }
+
 LaTeX::TikZ::Interface->register(
  line => sub {
   shift;
@@ -81,7 +93,7 @@ LaTeX::TikZ::Interface->register(
 LaTeX::TikZ::Functor->default_rule(
  (__PACKAGE__) => sub {
   my ($functor, $set, @args) = @_;
-  $set->new(map { $_ => $set->$_->$functor(@args) } qw/from to/)
+  $set->new(map { $_ => $set->$_->$functor(@args) } qw<from to>)
  }
 );
 
@@ -89,7 +101,7 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 SEE ALSO
 
-L<LaTeX::TikZ>, L<LaTeX::TikZ::Set::Op>.
+L<LaTeX::TikZ>, L<LaTeX::TikZ::Set::Path>.
 
 =head1 AUTHOR
 
@@ -110,7 +122,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
