@@ -9,27 +9,27 @@ LaTeX::TikZ::Set::Point - A set object representing a point.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use LaTeX::TikZ::Point;
 
 use LaTeX::TikZ::Interface;
 use LaTeX::TikZ::Functor;
 
-use Any::Moose;
-use Any::Moose 'Util::TypeConstraints';
+use Mouse;
+use Mouse::Util::TypeConstraints;
 
 =head1 RELATIONSHIPS
 
-This class consumes the L<LaTeX::TikZ::Set::Op> role, and as such implements the L</path> method.
+This class consumes the L<LaTeX::TikZ::Set::Path> role, and as such implements the L</path> method.
 
 =cut
 
-with 'LaTeX::TikZ::Set::Op';
+with 'LaTeX::TikZ::Set::Path';
 
 =head1 ATTRIBUTES
 
@@ -44,7 +44,7 @@ has 'point' => (
  isa      => 'LaTeX::TikZ::Point::Autocoerce',
  required => 1,
  coerce   => 1,
- handles  => [ qw/x y/ ],
+ handles  => [ qw<x y> ],
 );
 
 =head2 C<label>
@@ -114,6 +114,18 @@ sub path {
  $path;
 }
 
+=head2 C<begin>
+
+=cut
+
+sub begin { $_[0]->point }
+
+=head2 C<end>
+
+=cut
+
+sub end { $_[0]->point }
+
 LaTeX::TikZ::Interface->register(
  point => sub {
   shift;
@@ -146,7 +158,7 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 SEE ALSO
 
-L<LaTeX::TikZ>, L<LaTeX::TikZ::Set::Op>.
+L<LaTeX::TikZ>, L<LaTeX::TikZ::Set::Path>.
 
 =head1 AUTHOR
 
@@ -167,7 +179,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
