@@ -9,30 +9,30 @@ LaTeX::TikZ::Set::Raw - A literal chunk of TikZ code.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use LaTeX::TikZ::Interface;
 use LaTeX::TikZ::Functor;
 
-use Any::Moose;
+use Mouse;
 
 =head1 RELATIONSHIPS
 
-This class consumes the L<LaTeX::TikZ::Set::Op> role, and as such implements the L</path> method.
+This class consumes the L<LaTeX::TikZ::Set::Path> role, and as such implements the L</path> method.
 
 =cut
 
-with 'LaTeX::TikZ::Set::Op';
+with 'LaTeX::TikZ::Set::Path';
 
 =head1 ATTRIBUTES
 
 =head2 C<content>
 
-The bare string the raw mod is made of.
+The bare string the raw set is made of.
 
 =cut
 
@@ -50,6 +50,18 @@ has 'content' => (
 
 sub path { $_[0]->content }
 
+=head2 C<begin>
+
+=cut
+
+sub begin { undef }
+
+=head2 C<end>
+
+=cut
+
+sub end { undef }
+
 LaTeX::TikZ::Interface->register(
  raw => sub {
   shift;
@@ -69,7 +81,7 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 SEE ALSO
 
-L<LaTeX::TikZ>, L<LaTeX::TikZ::Set::Op>.
+L<LaTeX::TikZ>, L<LaTeX::TikZ::Set::Path>.
 
 =head1 AUTHOR
 
@@ -90,7 +102,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
