@@ -9,26 +9,26 @@ LaTeX::TikZ::Set::Rectangle - A set object representing a rectangle.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use LaTeX::TikZ::Set::Point;
 
 use LaTeX::TikZ::Interface;
 use LaTeX::TikZ::Functor;
 
-use Any::Moose;
+use Mouse;
 
 =head1 RELATIONSHIPS
 
-This class consumes the L<LaTeX::TikZ::Set::Op> role, and as such implements the L</path> method.
+This class consumes the L<LaTeX::TikZ::Set::Path> role, and as such implements the L</path> method.
 
 =cut
 
-with 'LaTeX::TikZ::Set::Op';
+with 'LaTeX::TikZ::Set::Path';
 
 =head1 ATTRIBUTES
 
@@ -92,6 +92,18 @@ sub path {
  $set->from->path(@_) . ' rectangle ' . $set->to->path(@_);
 }
 
+=head2 C<begin>
+
+=cut
+
+sub begin { $_[0]->from->begin }
+
+=head2 C<end>
+
+=cut
+
+sub end { $_[0]->to->end }
+
 my $meta = __PACKAGE__->meta;
 my $tc1  = $meta->find_attribute_by_name('from')->type_constraint;
 my $tc2  = $meta->find_attribute_by_name('to')->type_constraint;
@@ -116,7 +128,7 @@ Attributes 'width' and 'height' are required when 'to' was not given
    MSG
    $args{from} = $tc1->coerce($args{from});
    $meta->find_attribute_by_name($_)->type_constraint->assert_valid($args{$_})
-                                                      for qw/from width height/;
+                                                      for qw<from width height>;
    my $p = $args{from}->point;
    $args{to} = LaTeX::TikZ::Point->new(
     x => $p->x + $args{width},
@@ -138,7 +150,7 @@ LaTeX::TikZ::Interface->register(
 
   __PACKAGE__->new(
    from => $p,
-   ($is_relative ? (map +($_ => $q->{$_}), qw/width height/) : (to => $q)),
+   ($is_relative ? (map +($_ => $q->{$_}), qw<width height>) : (to => $q)),
   );
  },
 );
@@ -146,7 +158,7 @@ LaTeX::TikZ::Interface->register(
 LaTeX::TikZ::Functor->default_rule(
  (__PACKAGE__) => sub {
   my ($functor, $set, @args) = @_;
-  $set->new(map { $_ => $set->$_->$functor(@args) } qw/from to/)
+  $set->new(map { $_ => $set->$_->$functor(@args) } qw<from to>)
  }
 );
 
@@ -154,7 +166,7 @@ __PACKAGE__->meta->make_immutable;
 
 =head1 SEE ALSO
 
-L<LaTeX::TikZ>, L<LaTeX::TikZ::Set::Op>.
+L<LaTeX::TikZ>, L<LaTeX::TikZ::Set::Path>.
 
 =head1 AUTHOR
 
@@ -175,7 +187,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
