@@ -9,18 +9,21 @@ LaTeX::TikZ::Tools - Miscellaneous tools for LaTeX::TikZ classes.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-use Any::Moose 'Util::TypeConstraints' => [ 'find_type_constraint' ];
+use Mouse::Util::TypeConstraints 'find_type_constraint';
 
 =head1 CONSTANTS
 
 =head2 C<EPS>
 
+The numerical accuracy enforced by L</numeq>, L</numcmp> and L</numround>.
+It is currently set to C<1e-10>.
+
 =cut
 
 use constant EPS => 1e-10;
@@ -29,18 +32,30 @@ use constant EPS => 1e-10;
 
 =head2 C<numeq>
 
+    numeq($x, $y)
+
+Returns true if and only if C<$x> and C<$y> are equal up to L</EPS>.
+
 =cut
 
 sub numeq { abs($_[0] - $_[1]) < EPS }
 
 =head2 C<numcmp>
 
+    numcmp($x, $y)
+
+Returns a negative number, zero, or a positive number when C<$x> is respectively smaller than, equal to, or greater than C<$y> up to L</EPS>.
+
 =cut
 
 sub numcmp { $_[0] < $_[1] - EPS ? -1 : $_[0] > $_[1] + EPS ? 1 : 0 }
 
 =head2 C<numround>
 
+    numround($x)
+
+Returns the closest integer from C<$x> up to L</EPS>.
+
 =cut
 
 sub numround {
@@ -49,9 +64,11 @@ sub numround {
  $x + EPS < $i + 0.5 ? $i : $i + 1;
 }
 
-=head2 C<type_constraint $class>
+=head2 C<type_constraint>
 
-Find the type constraint for C<$class> by loading the relevant F<.pm> file beforehand.
+    my $tc = type_constraint($class)
+
+Finds the type constraint for C<$class> by first trying to load the relevant F<.pm> file.
 
 =cut
 
@@ -61,7 +78,13 @@ sub type_constraint {
  my $file = $class;
  $file =~ s{::}{/}g;
  $file .= '.pm';
- require $file;
+ unless ($INC{$file}) {
+  local $@;
+  eval {
+   local $SIG{__DIE__}; # See LaTeX::TikZ::Meta::TypeConstraint::Autocoerce
+   require $file;
+  }
+ }
 
  find_type_constraint($class);
 }
@@ -89,7 +112,7 @@ You can find documentation for this module with the perldoc command.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010 Vincent Pit, all rights reserved.
+Copyright 2010,2011,2012,2013,2014,2015 Vincent Pit, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
 
