@@ -1,6 +1,6 @@
 package LaTeX::TikZ::TestX::FromTestY;
 
-use Any::Moose 'Util::TypeConstraints';
+use Mouse::Util::TypeConstraints;
 
 coerce 'LaTeX::TikZ::TestX::Autocoerce'
     => from 'LaTeX::TikZ::TestY'
